/*
 * This program source code file is part of SystemK, a library in the KTag project.
 *
 * 🛡️ <https://ktag.clubk.club> 🃞
 *
 * Copyright © 2016-2025 Joseph P. Kearney and the KTag developers.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 *
 * There should be a copy of the GNU Affero General Public License in the LICENSE
 * file in the root of this repository.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "SystemK.h"

//! All the weapons, in the same order as #WeaponID_t.
Weapon_t WeaponsByID[NUMBER_OF_WEAPONS] = 
{
    // Test Pattern
    {
        .ID = TEST_PATTERN_ID,
        .Type = ENERGY,
        .Protocol = TEST_PROTOCOL,
        .Damage_Per_Shot = 1,
        .Shots_Per_Reload = UINT16_MAX,
        .Delay_Before_Sending_Shot_in_ms = 0,
        .Time_Between_Shots_in_ms = 1000,
        .Time_To_Reload_in_ms = 0
    },
    
    // Bayonette
    {
        .ID = BAYONETTE_ID,
        .Type = EDGE,
        .Protocol = MILES_TAG_II_PROTOCOL, // For now...
        .Damage_Per_Shot = 1,
        .Shots_Per_Reload = UINT16_MAX,
        .Delay_Before_Sending_Shot_in_ms = 0,
        .Time_Between_Shots_in_ms = 1000,
        .Time_To_Reload_in_ms = 0
    },
    
    // Pistol
    {
        .ID = PISTOL_ID,
        .Type = PROJECTILE,
        .Protocol = MILES_TAG_II_PROTOCOL, // For now...
        .Damage_Per_Shot = 10,
        .Shots_Per_Reload = 8,
        .Delay_Before_Sending_Shot_in_ms = 0,
        .Time_Between_Shots_in_ms = 300,
        .Time_To_Reload_in_ms = 3000
    },
    
    // Shotgun
    {
        .ID = SHOTGUN_ID,
        .Type = PROJECTILE,
        .Protocol = MILES_TAG_II_PROTOCOL, // For now...
        .Damage_Per_Shot = 20,
        .Shots_Per_Reload = 2,
        .Delay_Before_Sending_Shot_in_ms = 0,
        .Time_Between_Shots_in_ms = 500,
        .Time_To_Reload_in_ms = 10000
    },
    
    // Rifle
    {
        .ID = RIFLE_ID,
        .Type = PROJECTILE,
        .Protocol = MILES_TAG_II_PROTOCOL, // For now...
        .Damage_Per_Shot = 10,
        .Shots_Per_Reload = 8,
        .Delay_Before_Sending_Shot_in_ms = 0,
        .Time_Between_Shots_in_ms = 300,
        .Time_To_Reload_in_ms = 5000
    },
    
    // Machine Gun
    {
        .ID = MACHINE_GUN_ID,
        .Type = PROJECTILE,
        .Protocol = MILES_TAG_II_PROTOCOL, // For now...
        .Damage_Per_Shot = 10,
        .Shots_Per_Reload = 250,
        .Delay_Before_Sending_Shot_in_ms = 0,
        .Time_Between_Shots_in_ms = 0,
        .Time_To_Reload_in_ms = 2*60*1000
    },
    
    // Nerf Laser Ops Pro
    {
        .ID = NERF_LASER_OPS_ID,
        .Type = ENERGY,
        .Protocol = NERF_LASER_OPS_PRO_PROTOCOL,
        .Damage_Per_Shot = 10,
        .Shots_Per_Reload = 10,
        .Delay_Before_Sending_Shot_in_ms = 0,
        .Time_Between_Shots_in_ms = 300,
        .Time_To_Reload_in_ms = 3000
    },

    // Nerf Laser Strike Blaster
    {
        .ID = NERF_LASER_STRIKE_BLASTER_ID,
        .Type = ENERGY,
        .Protocol = NERF_LASER_STRIKE_PROTOCOL,
        .Damage_Per_Shot = 10,
        .Shots_Per_Reload = 12,
        .Delay_Before_Sending_Shot_in_ms = 0,
        .Time_Between_Shots_in_ms = 300,
        .Time_To_Reload_in_ms = 3000
    },
    
    // Nerf Phoenix LTX
    {
        .ID = NERF_PHOENIX_LTX_ID,
        .Type = ENERGY,
        .Protocol = NERF_PHOENIX_LTX_PROTOCOL,
        .Damage_Per_Shot = 10,
        .Shots_Per_Reload = 10,
        .Delay_Before_Sending_Shot_in_ms = 0,
        .Time_Between_Shots_in_ms = 300,
        .Time_To_Reload_in_ms = 3000
    },

    // Squad Hero Pistol
    {
        .ID = SQUAD_HERO_PISTOL,
        .Type = ENERGY,
        .Protocol = SQUAD_HERO_PROTOCOL,
        .Damage_Per_Shot = 1,
        .Shots_Per_Reload = 10,
        .Delay_Before_Sending_Shot_in_ms = 0,
        .Time_Between_Shots_in_ms = 300,
        .Time_To_Reload_in_ms = 3000
    },
    
    // Laser X
    {
        .ID = LASER_X_ID,
        .Type = ENERGY,
        .Protocol = LASER_X_PROTOCOL,
        .Damage_Per_Shot = 1,
        .Shots_Per_Reload = 10,
        .Delay_Before_Sending_Shot_in_ms = 0,
        .Time_Between_Shots_in_ms = 300,
        .Time_To_Reload_in_ms = 3000
    },
    
    // The Dubuque Protocol
    {
        .ID = DUBUQUE_PROTOCOL_ID,
        .Type = ENERGY,
        .Protocol = DUBUQUE_PROTOCOL,
        .Damage_Per_Shot = 1,
        .Shots_Per_Reload = 10,
        .Delay_Before_Sending_Shot_in_ms = 0,
        .Time_Between_Shots_in_ms = 300,
        .Time_To_Reload_in_ms = 3000
    }
};

