/*
 * This program source code file is part of SystemK, a library in the KTag project.
 *
 * 🛡️ <https://ktag.clubk.club> 🃞
 *
 * Copyright © 2016-2025 Joseph P. Kearney and the KTag developers.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 *
 * There should be a copy of the GNU Affero General Public License in the LICENSE
 * file in the root of this repository.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "SystemK.h"

static uint8_t SubmenuIndex = 0;
static MenuItem_T const * const Submenus[] = 
{
    &TeamIDMenuItem,
    &PlayerIDMenuItem
};
static const uint8_t N_SUBMENUS = (sizeof(Submenus) / sizeof(MenuItem_T *));

static const char * KLOG_TAG = "Menu | Game Settings";

static void OnFocus(bool IncludeDetails);
static MenuItem_T const * OnSelect();
static void OnIncrement();
static void OnDecrement();

const MenuItem_T GameMenuItem =
{
    .OnFocus = OnFocus,
    .OnSelect = OnSelect,
    .OnIncrement = OnIncrement,
    .OnDecrement = OnDecrement
    
};

static void OnFocus(bool IncludeDetails)
{
    AudioAction_T audio_action = {.ID = AUDIO_PLAY_GAME_SETTINGS_PROMPT, .Data = (void *)0x00};
    Perform_Audio_Action(&audio_action);

    KLOG_INFO(KLOG_TAG, "<--");
    
    if (IncludeDetails == true)
    {
        if (Submenus[SubmenuIndex]->OnFocus != NULL)
        {
            Submenus[SubmenuIndex]->OnFocus(false);
        }
    }
}

static MenuItem_T const * OnSelect()
{
    return Submenus[SubmenuIndex];
}

static void OnIncrement()
{
    if (SubmenuIndex < (N_SUBMENUS -1))
    {
        SubmenuIndex++;
    }
    else
    {
        // Wrap around.
        SubmenuIndex = 0;
    }
        
    if (Submenus[SubmenuIndex]->OnFocus != NULL)
    {
        Submenus[SubmenuIndex]->OnFocus(false);
    }
}

static void OnDecrement()
{
    if (SubmenuIndex > 0)
    {
        SubmenuIndex--;
    }
    else
    {
        // Wrap around.
        SubmenuIndex = (N_SUBMENUS -1);
    }    
        
    if (Submenus[SubmenuIndex]->OnFocus != NULL)
    {
        Submenus[SubmenuIndex]->OnFocus(false);
    }
}
