/*
 * This program source code file is part of SystemK, a library in the KTag project.
 *
 * 🛡️ <https://ktag.clubk.club> 🃞
 *
 * Copyright © 2016-2025 Joseph P. Kearney and the KTag developers.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 *
 * There should be a copy of the GNU Affero General Public License in the LICENSE
 * file in the root of this repository.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "SystemK.h"

#define MIN_TEAM_ID BASIC_TEAMS_MINIMUM
#define MAX_TEAM_ID BASIC_TEAMS_MAXIMUM

static const char * KLOG_TAG = "Team ID Menu";

static uint8_t Team_ID;

static void OnFocus(bool IncludeDetails);
static MenuItem_T const * OnSelect();
static void OnIncrement();
static void OnDecrement();

const MenuItem_T TeamIDMenuItem =
{
    .OnFocus = OnFocus,
    .OnSelect = OnSelect,
    .OnIncrement = OnIncrement,
    .OnDecrement = OnDecrement
    
};

static void OnFocus(bool IncludeDetails)
{
    AudioAction_T audio_action = {.ID = AUDIO_PLAY_TEAM_ID_PROMPT, .Play_To_Completion = true, .Data = (void *)0x00};
    Perform_Audio_Action(&audio_action);
    
    if (IncludeDetails == true)
    {
        (void) SETTINGS_get_uint8_t(SYSTEMK_SETTING_TEAMID, &Team_ID);
        AudioAction_T volume_action = {.ID = AUDIO_PRONOUNCE_NUMBER_0_TO_100, .Play_To_Completion = true, .Data = (void *)&Team_ID};
        Perform_Audio_Action(&volume_action);
    }
}

static MenuItem_T const * OnSelect()
{
    AudioAction_T audio_action = {.ID = AUDIO_PLAY_SELECTION_INDICATOR, .Data = (void *)0x00};
    Perform_Audio_Action(&audio_action);
    return NULL;
}

static void OnIncrement()
{
    (void) SETTINGS_get_uint8_t(SYSTEMK_SETTING_TEAMID, &Team_ID);

    if (Team_ID < MAX_TEAM_ID)
    {
        Team_ID++;
    }
    else
    {
        Team_ID = MAX_TEAM_ID;
    }

    if (Set_Team_With_Audio_Feedback(Team_ID) != SYSTEMK_RESULT_SUCCESS)
    {
        KLOG_WARN(KLOG_TAG, "Failed to increment team!");
    }
}

static void OnDecrement()
{
    (void) SETTINGS_get_uint8_t(SYSTEMK_SETTING_TEAMID, &Team_ID);

    if (Team_ID > MIN_TEAM_ID)
    {
        Team_ID--;
    }
    else
    {
        Team_ID = MIN_TEAM_ID;
    }

    if (Set_Team_With_Audio_Feedback(Team_ID) != SYSTEMK_RESULT_SUCCESS)
    {
        KLOG_WARN(KLOG_TAG, "Failed to decrement team!");
    }
}