/*
 * This program source code file is part of SystemK, a library in the KTag project.
 *
 * 🛡️ <https://ktag.clubk.club> 🃞
 *
 * Copyright © 2016-2025 Joseph P. Kearney and the KTag developers.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 *
 * There should be a copy of the GNU Affero General Public License in the LICENSE
 * file in the root of this repository.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "SystemK.h"

static uint8_t Is_Right_Handed;

static void OnFocus(bool IncludeDetails);
static MenuItem_T const * OnSelect();
static void OnIncrement();
static void OnDecrement();
static void ToggleHanded();

const MenuItem_T HandedMenuItem =
{
    .OnFocus = OnFocus,
    .OnSelect = OnSelect,
    .OnIncrement = OnIncrement,
    .OnDecrement = OnDecrement
    
};

static void OnFocus(bool IncludeDetails)
{
    (void) SETTINGS_get_uint8_t(SYSTEMK_SETTING_IS_RIGHT_HANDED, &Is_Right_Handed);
    if (Is_Right_Handed == true)
    {
        AudioAction_T audio_action = {.ID = AUDIO_PLAY_RIGHT_HANDED, .Play_To_Completion = true, .Data = (void *)0x00};
        Perform_Audio_Action(&audio_action);
    }
    else
    {
        AudioAction_T audio_action = {.ID = AUDIO_PLAY_LEFT_HANDED, .Play_To_Completion = true, .Data = (void *)0x00};
        Perform_Audio_Action(&audio_action);;
    }
}

static MenuItem_T const * OnSelect()
{
    AudioAction_T audio_action = {.ID = AUDIO_PLAY_SELECTION_INDICATOR, .Data = (void *)0x00};
    Perform_Audio_Action(&audio_action);
    return NULL;
}

static void OnIncrement()
{
    ToggleHanded();
}

static void OnDecrement()
{
    ToggleHanded();
}

static void ToggleHanded()
{
    uint8_t Is_Right_Handed;
    (void) SETTINGS_get_uint8_t(SYSTEMK_SETTING_IS_RIGHT_HANDED, &Is_Right_Handed);
    
    if (Is_Right_Handed == true)
    {
        Is_Right_Handed = false;
        (void) SETTINGS_set_uint8_t(SYSTEMK_SETTING_IS_RIGHT_HANDED, Is_Right_Handed);
        AudioAction_T audio_action = {.ID = AUDIO_PLAY_LEFT_HANDED, .Play_To_Completion = true, .Data = (void *)0x00};
        Perform_Audio_Action(&audio_action);
    }
    else
    {
        Is_Right_Handed = true;
        (void) SETTINGS_set_uint8_t(SYSTEMK_SETTING_IS_RIGHT_HANDED, Is_Right_Handed);
        AudioAction_T audio_action = {.ID = AUDIO_PLAY_RIGHT_HANDED, .Play_To_Completion = true, .Data = (void *)0x00};
        Perform_Audio_Action(&audio_action);;
    }
}
