/*
 * This program source code file is part of SystemK, a library in the KTag project.
 *
 * 🛡️ <https://ktag.clubk.club> 🃞
 *
 * Copyright © 2016-2025 Joseph P. Kearney and the KTag developers.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 *
 * There should be a copy of the GNU Affero General Public License in the LICENSE
 * file in the root of this repository.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "SystemK.h"

#define MAX_VOLUME (CONFIG_KTAG_MAX_AUDIO_VOLUME)
#if (MAX_VOLUME > 100)
    #error "CONFIG_KTAG_MAX_AUDIO_VOLUME is too large.  Volume has to be between 0 and 100."
#endif
#define MIN_VOLUME (CONFIG_KTAG_MIN_AUDIO_VOLUME)
#if (MAX_VOLUME < MIN_VOLUME)
    #error "CONFIG_KTAG_MAX_AUDIO_VOLUME is less than CONFIG_KTAG_MIN_AUDIO_VOLUME.  Something is not quite right."
#endif

static uint8_t Volume;
static const char * KLOG_TAG = "Menu | Volume";

static void OnFocus(bool IncludeDetails);
static MenuItem_T const * OnSelect();
static void OnIncrement();
static void OnDecrement();

const MenuItem_T VolumeMenuItem =
{
    .OnFocus = OnFocus,
    .OnSelect = OnSelect,
    .OnIncrement = OnIncrement,
    .OnDecrement = OnDecrement
    
};

static void OnFocus(bool IncludeDetails)
{
    (void) SETTINGS_get_uint8_t(SYSTEMK_SETTING_AUDIO_VOLUME, &Volume);
    
    AudioAction_T audio_action = {.ID = AUDIO_PLAY_VOLUME_PROMPT, .Play_To_Completion = true, .Data = (void *)0x00};
    Perform_Audio_Action(&audio_action);
    
    if (IncludeDetails == true)
    {                    
        AudioAction_T volume_action = {.ID = AUDIO_PRONOUNCE_NUMBER_0_TO_100, .Play_To_Completion = true, .Data = (void *)&Volume};
        Perform_Audio_Action(&volume_action);
    }
}

static MenuItem_T const * OnSelect()
{
    AudioAction_T audio_action = {.ID = AUDIO_PLAY_SELECTION_INDICATOR, .Data = (void *)0x00};
    Perform_Audio_Action(&audio_action);
    return NULL;
}

static void OnIncrement()
{
    (void) SETTINGS_get_uint8_t(SYSTEMK_SETTING_AUDIO_VOLUME, &Volume);
    
    if (Volume < MAX_VOLUME)
    {
        Volume++;
    }
    
    KLOG_INFO(KLOG_TAG, "Volume incremented--is now %u. (Max is %u.)", Volume, MAX_VOLUME);
    
    (void) SETTINGS_set_uint8_t(SYSTEMK_SETTING_AUDIO_VOLUME, Volume);
    
    AudioAction_T set_volume_action = {.ID = AUDIO_SET_VOLUME, .Data = (void *)&Volume};
    Perform_Audio_Action(&set_volume_action);
    
    AudioAction_T audio_action = {.ID = AUDIO_PLAY_VOLUME_PROMPT, .Play_To_Completion = true, .Data = (void *)0x00};
    Perform_Audio_Action(&audio_action);
                        
    AudioAction_T volume_action = {.ID = AUDIO_PRONOUNCE_NUMBER_0_TO_100, .Play_To_Completion = true, .Data = (void *)&Volume};
    Perform_Audio_Action(&volume_action);
}

static void OnDecrement()
{
    (void) SETTINGS_get_uint8_t(SYSTEMK_SETTING_AUDIO_VOLUME, &Volume);
    
    if (Volume > MIN_VOLUME)
    {
        Volume--;
    }
    
    KLOG_INFO(KLOG_TAG, "Volume decremented--is now %u. (Min is %u.)", Volume, MIN_VOLUME);
        
    (void) SETTINGS_set_uint8_t(SYSTEMK_SETTING_AUDIO_VOLUME, Volume);
    
    AudioAction_T set_volume_action = {.ID = AUDIO_SET_VOLUME, .Data = (void *)&Volume};
    Perform_Audio_Action(&set_volume_action);
    
    AudioAction_T audio_action = {.ID = AUDIO_PLAY_VOLUME_PROMPT, .Play_To_Completion = true, .Data = (void *)0x00};
    Perform_Audio_Action(&audio_action);
                        
    AudioAction_T volume_action = {.ID = AUDIO_PRONOUNCE_NUMBER_0_TO_100, .Play_To_Completion = true, .Data = (void *)&Volume};
    Perform_Audio_Action(&volume_action);
}