/*
 * This program source code file is part of SystemK, a library in the KTag project.
 *
 * 🛡️ <https://ktag.clubk.club> 🃞
 *
 * Copyright © 2016-2025 Joseph P. Kearney and the KTag developers.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 *
 * There should be a copy of the GNU Affero General Public License in the LICENSE
 * file in the root of this repository.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "SystemK.h"

static uint8_t SubmenuIndex = 0;
static MenuItem_T const * const Submenus[] = 
{
    &GameMenuItem,
    &HardwareMenuItem
};
static const uint8_t N_SUBMENUS = (sizeof(Submenus) / sizeof(MenuItem_T *));

static void RootMenuOnFocus(bool IncludeDetails);
static MenuItem_T const * RootMenuOnSelect();
static void RootMenuOnIncrement();
static void RootMenuOnDecrement();

static const MenuItem_T Root_Menu_Item =
{
    .OnFocus = RootMenuOnFocus,
    .OnSelect = RootMenuOnSelect,
    .OnIncrement = RootMenuOnIncrement,
    .OnDecrement = RootMenuOnDecrement
    
};

MenuItem_T const * const RootMenu = &Root_Menu_Item;

static void RootMenuOnFocus(bool IncludeDetails)
{
    AudioAction_T audio_action = {.ID = AUDIO_PLAY_MENU_PROMPT, .Play_To_Completion = true, .Data = (void *)0x00};
    Perform_Audio_Action(&audio_action);
    
    if (IncludeDetails == true)
    {
        if (Submenus[SubmenuIndex]->OnFocus != NULL)
        {
            Submenus[SubmenuIndex]->OnFocus(false);
        }
    }
}

static MenuItem_T const * RootMenuOnSelect()
{
    if (Submenus[SubmenuIndex]->OnSelect != NULL)
    {
        Submenus[SubmenuIndex]->OnSelect();
    }
    
    return Submenus[SubmenuIndex];
}

static void RootMenuOnIncrement()
{
    if (SubmenuIndex < (N_SUBMENUS -1))
    {
        SubmenuIndex++;
    }
    else
    {
        // Wrap around.
        SubmenuIndex = 0;
    }
        
    if (Submenus[SubmenuIndex]->OnFocus != NULL)
    {
        Submenus[SubmenuIndex]->OnFocus(false);
    }
}

static void RootMenuOnDecrement()
{
    if (SubmenuIndex > 0)
    {
        SubmenuIndex--;
    }
    else
    {
        // Wrap around.
        SubmenuIndex = (N_SUBMENUS -1);
    }    
        
    if (Submenus[SubmenuIndex]->OnFocus != NULL)
    {
        Submenus[SubmenuIndex]->OnFocus(false);
    }
}