
/*
 * This program source code file is part of SystemK, a library in the KTag project.
 *
 * 🛡️ <https://ktag.clubk.club> 🃞
 *
 * Copyright © 2016-2025 Joseph P. Kearney and the KTag developers.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 *
 * There should be a copy of the GNU Affero General Public License in the LICENSE
 * file in the root of this repository.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DYNASTY_H
#define DYNASTY_H

/** \file
 *  \brief This is the Dynasty protocol.
 *
 *  \note These devices use a 38kHz carrier.  The modulation scheme is a little more complicated
 *        than on-off keying: the width of each mark or space represents one bit of data.  This
 *        results in a more time-efficient data packet.
 *
 *  https://dynastytoys.co/
 *
 */

#include <stdbool.h>
#include <stdint.h>

TimedPulseTrain_T *DYNASTY_EncodePacket(TagPacket_T *packet);
DecodedPacket_T *DYNASTY_MaybeDecodePacket(TimedPulseTrain_T *packet);
color_t DYNASTY_GetTeamColor(uint8_t team_ID);

#endif // DYNASTY_H
